==> roundtripper-0.1.0.tar.gz: lib/src/client.dart <==
import 'dart:io';
import 'dart:typed_data';

import 'package:dio/dio.dart' show HttpClientAdapter, RequestOptions;

import 'adapter.dart';
import 'interfaces.dart';
import 'request.dart';
import 'response.dart';

typedef Conn = HttpClientAdapter Function();

class Client {
  final List<RoundTripBuilder> roundTripBuilders;
  late Conn conn;

  Client({
    Conn? conn,
    this.roundTripBuilders = const [],
  }) {
    this.conn = conn ?? createAdapter;
  }

  Future<Response> fetch(Request request) {
    RoundTrip rt = _send;
    for (var n = roundTripBuilders.length - 1; n >= 0; n--) {
      rt = roundTripBuilders[n].build(rt);
    }
    return rt(request);
  }

  Future<Response> _send(Request request) async {
    var c = conn();

    try {
      var resp = await c.fetch(
        RequestOptions(
          method: request.method,
          path: request.uri.toString(),
          headers: request.headers?.map(
            (key, value) =>
                MapEntry(key, value is List ? value.join(", ") : value),
          ),
          validateStatus: (i) => true,
        ),
        request.requestBody?.map((list) => Uint8List.fromList(list)),
        request.cancelToken?.whenCancel,
      );

      return Response(
        request: request,
        statusCode: resp.statusCode ?? -1,
        headers: resp.headers,
        responseBody: resp.stream.map((list) => list.toList()),
      );
    } catch (e) {
      if (e is SocketException && e.message.contains('cancelled')) {
        var cancelError = request.cancelToken?.cancelError;
        if (cancelError != null) {
          throw cancelError;
        }
      }
      rethrow;
    } finally {
      c.close();
    }
  }
}

==> roundtripper-0.2.0.tar.gz: lib/src/client.dart <==
import 'dart:io' show SocketException, HttpStatus;
import 'dart:typed_data';

import 'package:dio/dio.dart' show HttpClientAdapter, RequestOptions;

import 'adapter.dart';
import 'interfaces.dart';
import 'request.dart';
import 'response.dart';

typedef Conn = HttpClientAdapter Function();

class Client {
  final List<RoundTripBuilder> roundTripBuilders;
  late Conn conn;

  Client({
    Conn? conn,
    this.roundTripBuilders = const [],
  }) {
    this.conn = conn ?? createAdapter;
  }

  Future<Response> fetch(Request request) {
    RoundTrip rt = _send;
    for (var n = roundTripBuilders.length - 1; n >= 0; n--) {
      rt = roundTripBuilders[n].build(rt);
    }
    return rt(request);
  }

  Future<Response> _send(Request request) async {
    var c = conn();

    try {
      var resp = await c.fetch(
        RequestOptions(
          method: request.method,
          path: request.uri.toString(),
          headers: request.headers?.map(
            (key, value) =>
                MapEntry(key, value is List ? value.join(", ") : value),
          ),
          validateStatus: (i) => true,
        ),
        request.requestBody?.map((list) => Uint8List.fromList(list)),
        request.context
            ?.done()
            ?.map(
              (e) => ErrorResponse.fromException(
                  HttpStatus.clientClosedRequest, e),
            )
            .first,
      );

      return Response(
        request: request,
        statusCode: resp.statusCode ?? -1,
        headers: resp.headers,
        responseBody: resp.stream.map((list) => list.toList()),
      );
    } catch (e) {
      if (e is SocketException && e.message.contains('cancelled')) {
        var cancelError = request.context?.err();
        if (cancelError != null) {
          throw ErrorResponse.fromException(
              HttpStatus.clientClosedRequest, cancelError);
        }
      }
      rethrow;
    } finally {
      c.close();
    }
  }
}
